/*
 * Copyright (C) 2002 Roman Zippel <zippel@linux-m68k.org>
 * Released under the terms of the GNU GPL v2.0.
 */

#include <qlistview.h>

class ConfigItem : public QListViewItem {
public:
	ConfigItem(QListView *parent, ConfigItem *after, struct menu *m)
	: QListViewItem(parent, after), menu(m)
	{
		init();
	}
	ConfigItem(ConfigItem *parent, ConfigItem *after, struct menu *m)
	: QListViewItem(parent, after), menu(m)
	{
		init();
	}
	~ConfigItem(void)
	{
		menu->data = 0;
	}
	void init(void);
#if QT_VERSION >= 300
	void okRename(int col);
#endif
	void updateMenu(void);

	struct menu *menu;
#if QT_VERSION < 300
	void setEnabled(bool b)
	{
		enabled = b;
	}
	bool enabled;
#endif
};

#if QT_VERSION < 300
class ConfigLineEdit : public QLineEdit {
	Q_OBJECT
public:
	ConfigLineEdit(QWidget * parent)
	: QLineEdit(parent)
	{ }
	void show(ConfigItem *i);
	void keyPressEvent(QKeyEvent *e);

	ConfigItem *item;
};
#endif

class ConfigList : public QListView {
	Q_OBJECT
public:
	ConfigList(QWidget *p);
	void updateMenu(void);

#if QT_VERSION < 300
	ConfigLineEdit *lineEdit;
#endif

public slots:
	void setValue(QListViewItem* item, const QPoint& pnt, int c);
	void changeValue(QListViewItem* item);
};

class ConfigView : public QVBox {
	Q_OBJECT
public:
	ConfigView(void);
public slots:
	void setHelp(QListViewItem* item);

protected:
	void closeEvent(QCloseEvent *e);

	ConfigList *configList;
	QTextView *helpText;
};
